#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Singleton Pattern
"""

class Singleton(object):  
    def __new__(cls, *args, **kw):  
        if not hasattr(cls, '_instance'):  
            orig = super(Singleton, cls)  
            cls._instance = orig.__new__(cls, *args, **kw)  
        return cls._instance  
